@@ -128,6 +128,7 @@ impl NumberInstance for Number {
     type Abs = Number;
     type Exp = Self;
     type Log = Self;
+    type Round = Self;
     type Class = NumberType;
 
     fn class(&self) -> NumberType {
@@ -230,6 +231,14 @@ impl NumberInstance for Number {
             Self::Bool(b) => Self::Bool(b.pow(exp)),
         }
     }
+
+    fn round(self) -> Self::Round {
+        match self {
+            Self::Complex(c) => c.round().into(),
+            Self::Float(f) => f.round().into(),
+            other => other,
+        }
+    }
 }
 
 impl FloatInstance for Number {
